"""The Jupyter notebook data."""
from typing import Dict, Union

from nbformat import NotebookNode

Data = Dict[str, Union[str, NotebookNode]]
